# coding: utf-8

"""
EventsApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class EventsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def close_ongoing_event(self, s, n, **kwargs):
        """
        Close an event
        Method is idempotent. The closed event is returned.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.close_ongoing_event(s, n, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int s: start time of the event to close in milliseconds (required)
        :param str n: name of the event to close (required)
        :param int e: end time of the event to close (null will use current time) in milliseconds
        :return: ReportEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['s', 'n', 'e']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method close_ongoing_event" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 's' is set
        if ('s' not in params) or (params['s'] is None):
            raise ValueError("Missing the required parameter `s` when calling `close_ongoing_event`")
        # verify the required parameter 'n' is set
        if ('n' not in params) or (params['n'] is None):
            raise ValueError("Missing the required parameter `n` when calling `close_ongoing_event`")

        resource_path = '/api/events/close'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 's' in params:
            form_params.append(('s', params['s']))
        if 'n' in params:
            form_params.append(('n', params['n']))
        if 'e' in params:
            form_params.append(('e', params['e']))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/x-www-form-urlencoded'])

        # Authentication setting
        auth_settings = ['api_key']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ReportEvent',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def create_new_event(self, n, **kwargs):
        """
        Create a new event
        The created event is returned.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_new_event(n, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str n: name for the event (required)
        :param int s: start time for the event in milliseconds
        :param int e: end time for the event in milliseconds
        :param bool c: flag for instantaneous event
        :param str d: additional details for the event
        :param list[str] h: set of hosts affected by this event
        :param str l: severity of the event
        :param str t: event type
        :return: ReportEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['n', 's', 'e', 'c', 'd', 'h', 'l', 't']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_new_event" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'n' is set
        if ('n' not in params) or (params['n'] is None):
            raise ValueError("Missing the required parameter `n` when calling `create_new_event`")

        resource_path = '/api/events'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'n' in params:
            form_params.append(('n', params['n']))
        if 's' in params:
            form_params.append(('s', params['s']))
        if 'e' in params:
            form_params.append(('e', params['e']))
        if 'c' in params:
            form_params.append(('c', params['c']))
        if 'd' in params:
            form_params.append(('d', params['d']))
        if 'h' in params:
            form_params.append(('h', params['h']))
        if 'l' in params:
            form_params.append(('l', params['l']))
        if 't' in params:
            form_params.append(('t', params['t']))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client. \
            select_header_content_type(['application/x-www-form-urlencoded'])

        # Authentication setting
        auth_settings = ['api_key']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ReportEvent',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_event(self, start_time, name, **kwargs):
        """
        Delete an event. Can only delete non-system events. System events include alert firings, error events, and maintenance windows
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_event(start_time, name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int start_time: start time of the event to delete in milliseconds (required)
        :param str name: name of the event (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'name']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_event" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'start_time' is set
        if ('start_time' not in params) or (params['start_time'] is None):
            raise ValueError("Missing the required parameter `start_time` when calling `delete_event`")
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `delete_event`")

        resource_path = '/api/events/{startTime}/{name}'.replace('{format}', 'json')
        path_params = {}
        if 'start_time' in params:
            path_params['startTime'] = params['start_time']
        if 'name' in params:
            path_params['name'] = params['name']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['api_key']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
